:orphan:

.. unified index page included for backwards compatibility

******************
Scenario Guides
******************

The guides in this section are migrating into collections. Remaining guides may be out of date.

These guides cover integrating Ansible with a variety of platforms, products, and technologies. They explore particular use cases in greater depth and provide a more "top-down" explanation of some basic features.

We are migrating these guides into collections. Please update your links for the following guides:

:ref:`ansible_collections.amazon.aws.docsite.aws_intro`

.. toctree::
   :maxdepth: 1
   :caption: Legacy Public Cloud Guides

   guide_alicloud
   guide_cloudstack
   guide_gce
   guide_azure
   guide_online
   guide_oracle
   guide_packet
   guide_rax
   guide_scaleway
   guide_vultr

.. toctree::
   :maxdepth: 1
   :caption: Network Technology Guides

   guide_aci
   guide_meraki
   guide_infoblox

.. toctree::
   :maxdepth: 1
   :caption: Virtualization & Containerization Guides

   guide_kubernetes
   guide_vagrant
   guide_vmware
